package org.xtext.example.mydsl.serializer;

import com.google.inject.Inject;
import com.google.inject.Provider;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.xtext.serializer.acceptor.ISemanticSequenceAcceptor;
import org.eclipse.xtext.serializer.acceptor.SequenceFeeder;
import org.eclipse.xtext.serializer.diagnostic.ISemanticSequencerDiagnosticProvider;
import org.eclipse.xtext.serializer.diagnostic.ISerializationDiagnostic.Acceptor;
import org.eclipse.xtext.serializer.sequencer.AbstractDelegatingSemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.GenericSequencer;
import org.eclipse.xtext.serializer.sequencer.ISemanticNodeProvider.INodesForEObjectProvider;
import org.eclipse.xtext.serializer.sequencer.ISemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService.ValueTransient;
import org.xtext.example.mydsl.myDsl.BinaryBooleanExpression;
import org.xtext.example.mydsl.myDsl.BooleanLiteral;
import org.xtext.example.mydsl.myDsl.Comparison;
import org.xtext.example.mydsl.myDsl.DoubleLiteral;
import org.xtext.example.mydsl.myDsl.FormalParameter;
import org.xtext.example.mydsl.myDsl.Function;
import org.xtext.example.mydsl.myDsl.IfElseExpression;
import org.xtext.example.mydsl.myDsl.IntLiteral;
import org.xtext.example.mydsl.myDsl.Model;
import org.xtext.example.mydsl.myDsl.MyDslPackage;
import org.xtext.example.mydsl.myDsl.Power;
import org.xtext.example.mydsl.myDsl.Product;
import org.xtext.example.mydsl.myDsl.Term;
import org.xtext.example.mydsl.myDsl.UnaryBooleanExpression;
import org.xtext.example.mydsl.services.MyDslGrammarAccess;

@SuppressWarnings("all")
public class MyDslSemanticSequencer extends AbstractDelegatingSemanticSequencer {

	@Inject
	private MyDslGrammarAccess grammarAccess;
	
	public void createSequence(EObject context, EObject semanticObject) {
		if(semanticObject.eClass().getEPackage() == MyDslPackage.eINSTANCE) switch(semanticObject.eClass().getClassifierID()) {
			case MyDslPackage.BINARY_BOOLEAN_EXPRESSION:
				if(context == grammarAccess.getAtomRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionAccess().getBinaryBooleanExpressionLeftAction_1_0() ||
				   context == grammarAccess.getComparisonRule() ||
				   context == grammarAccess.getComparisonAccess().getComparisonLeftAction_1_0() ||
				   context == grammarAccess.getIfElseExpressionRule() ||
				   context == grammarAccess.getIfElseExpressionAccess().getIfElseExpressionConditionAction_1_0() ||
				   context == grammarAccess.getPowerRule() ||
				   context == grammarAccess.getPowerAccess().getPowerBaseAction_1_0() ||
				   context == grammarAccess.getProductRule() ||
				   context == grammarAccess.getProductAccess().getProductLeftAction_1_0() ||
				   context == grammarAccess.getRootExpressionRule() ||
				   context == grammarAccess.getTermRule() ||
				   context == grammarAccess.getTermAccess().getTermLeftAction_1_0() ||
				   context == grammarAccess.getUnaryBooleanExpressionRule() ||
				   context == grammarAccess.getUnaryBooleanExpressionAccess().getUnaryBooleanExpressionInnerAction_0_2()) {
					sequence_BinaryBooleanExpression(context, (BinaryBooleanExpression) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.BOOLEAN_LITERAL:
				if(context == grammarAccess.getAtomRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionAccess().getBinaryBooleanExpressionLeftAction_1_0() ||
				   context == grammarAccess.getBooleanLiteralRule() ||
				   context == grammarAccess.getComparisonRule() ||
				   context == grammarAccess.getComparisonAccess().getComparisonLeftAction_1_0() ||
				   context == grammarAccess.getIfElseExpressionRule() ||
				   context == grammarAccess.getIfElseExpressionAccess().getIfElseExpressionConditionAction_1_0() ||
				   context == grammarAccess.getLiteralRule() ||
				   context == grammarAccess.getPowerRule() ||
				   context == grammarAccess.getPowerAccess().getPowerBaseAction_1_0() ||
				   context == grammarAccess.getProductRule() ||
				   context == grammarAccess.getProductAccess().getProductLeftAction_1_0() ||
				   context == grammarAccess.getRootExpressionRule() ||
				   context == grammarAccess.getTermRule() ||
				   context == grammarAccess.getTermAccess().getTermLeftAction_1_0() ||
				   context == grammarAccess.getUnaryBooleanExpressionRule() ||
				   context == grammarAccess.getUnaryBooleanExpressionAccess().getUnaryBooleanExpressionInnerAction_0_2()) {
					sequence_BooleanLiteral(context, (BooleanLiteral) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.COMPARISON:
				if(context == grammarAccess.getAtomRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionAccess().getBinaryBooleanExpressionLeftAction_1_0() ||
				   context == grammarAccess.getComparisonRule() ||
				   context == grammarAccess.getComparisonAccess().getComparisonLeftAction_1_0() ||
				   context == grammarAccess.getIfElseExpressionRule() ||
				   context == grammarAccess.getIfElseExpressionAccess().getIfElseExpressionConditionAction_1_0() ||
				   context == grammarAccess.getPowerRule() ||
				   context == grammarAccess.getPowerAccess().getPowerBaseAction_1_0() ||
				   context == grammarAccess.getProductRule() ||
				   context == grammarAccess.getProductAccess().getProductLeftAction_1_0() ||
				   context == grammarAccess.getRootExpressionRule() ||
				   context == grammarAccess.getTermRule() ||
				   context == grammarAccess.getTermAccess().getTermLeftAction_1_0() ||
				   context == grammarAccess.getUnaryBooleanExpressionRule() ||
				   context == grammarAccess.getUnaryBooleanExpressionAccess().getUnaryBooleanExpressionInnerAction_0_2()) {
					sequence_Comparison(context, (Comparison) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.DOUBLE_LITERAL:
				if(context == grammarAccess.getAtomRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionAccess().getBinaryBooleanExpressionLeftAction_1_0() ||
				   context == grammarAccess.getComparisonRule() ||
				   context == grammarAccess.getComparisonAccess().getComparisonLeftAction_1_0() ||
				   context == grammarAccess.getDoubleLiteralRule() ||
				   context == grammarAccess.getIfElseExpressionRule() ||
				   context == grammarAccess.getIfElseExpressionAccess().getIfElseExpressionConditionAction_1_0() ||
				   context == grammarAccess.getLiteralRule() ||
				   context == grammarAccess.getNumberLiteralRule() ||
				   context == grammarAccess.getPowerRule() ||
				   context == grammarAccess.getPowerAccess().getPowerBaseAction_1_0() ||
				   context == grammarAccess.getProductRule() ||
				   context == grammarAccess.getProductAccess().getProductLeftAction_1_0() ||
				   context == grammarAccess.getRootExpressionRule() ||
				   context == grammarAccess.getTermRule() ||
				   context == grammarAccess.getTermAccess().getTermLeftAction_1_0() ||
				   context == grammarAccess.getUnaryBooleanExpressionRule() ||
				   context == grammarAccess.getUnaryBooleanExpressionAccess().getUnaryBooleanExpressionInnerAction_0_2()) {
					sequence_DoubleLiteral(context, (DoubleLiteral) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.FORMAL_PARAMETER:
				if(context == grammarAccess.getAtomRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionAccess().getBinaryBooleanExpressionLeftAction_1_0() ||
				   context == grammarAccess.getComparisonRule() ||
				   context == grammarAccess.getComparisonAccess().getComparisonLeftAction_1_0() ||
				   context == grammarAccess.getFormalParameterRule() ||
				   context == grammarAccess.getIfElseExpressionRule() ||
				   context == grammarAccess.getIfElseExpressionAccess().getIfElseExpressionConditionAction_1_0() ||
				   context == grammarAccess.getLiteralRule() ||
				   context == grammarAccess.getPowerRule() ||
				   context == grammarAccess.getPowerAccess().getPowerBaseAction_1_0() ||
				   context == grammarAccess.getProductRule() ||
				   context == grammarAccess.getProductAccess().getProductLeftAction_1_0() ||
				   context == grammarAccess.getRootExpressionRule() ||
				   context == grammarAccess.getTermRule() ||
				   context == grammarAccess.getTermAccess().getTermLeftAction_1_0() ||
				   context == grammarAccess.getUnaryBooleanExpressionRule() ||
				   context == grammarAccess.getUnaryBooleanExpressionAccess().getUnaryBooleanExpressionInnerAction_0_2()) {
					sequence_FormalParameter(context, (FormalParameter) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.FUNCTION:
				if(context == grammarAccess.getAtomRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionAccess().getBinaryBooleanExpressionLeftAction_1_0() ||
				   context == grammarAccess.getComparisonRule() ||
				   context == grammarAccess.getComparisonAccess().getComparisonLeftAction_1_0() ||
				   context == grammarAccess.getFunctionRule() ||
				   context == grammarAccess.getIfElseExpressionRule() ||
				   context == grammarAccess.getIfElseExpressionAccess().getIfElseExpressionConditionAction_1_0() ||
				   context == grammarAccess.getPowerRule() ||
				   context == grammarAccess.getPowerAccess().getPowerBaseAction_1_0() ||
				   context == grammarAccess.getProductRule() ||
				   context == grammarAccess.getProductAccess().getProductLeftAction_1_0() ||
				   context == grammarAccess.getRootExpressionRule() ||
				   context == grammarAccess.getTermRule() ||
				   context == grammarAccess.getTermAccess().getTermLeftAction_1_0() ||
				   context == grammarAccess.getUnaryBooleanExpressionRule() ||
				   context == grammarAccess.getUnaryBooleanExpressionAccess().getUnaryBooleanExpressionInnerAction_0_2()) {
					sequence_Function(context, (Function) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.IF_ELSE_EXPRESSION:
				if(context == grammarAccess.getAtomRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionAccess().getBinaryBooleanExpressionLeftAction_1_0() ||
				   context == grammarAccess.getComparisonRule() ||
				   context == grammarAccess.getComparisonAccess().getComparisonLeftAction_1_0() ||
				   context == grammarAccess.getIfElseExpressionRule() ||
				   context == grammarAccess.getIfElseExpressionAccess().getIfElseExpressionConditionAction_1_0() ||
				   context == grammarAccess.getPowerRule() ||
				   context == grammarAccess.getPowerAccess().getPowerBaseAction_1_0() ||
				   context == grammarAccess.getProductRule() ||
				   context == grammarAccess.getProductAccess().getProductLeftAction_1_0() ||
				   context == grammarAccess.getRootExpressionRule() ||
				   context == grammarAccess.getTermRule() ||
				   context == grammarAccess.getTermAccess().getTermLeftAction_1_0() ||
				   context == grammarAccess.getUnaryBooleanExpressionRule() ||
				   context == grammarAccess.getUnaryBooleanExpressionAccess().getUnaryBooleanExpressionInnerAction_0_2()) {
					sequence_IfElseExpression(context, (IfElseExpression) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.INT_LITERAL:
				if(context == grammarAccess.getAtomRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionAccess().getBinaryBooleanExpressionLeftAction_1_0() ||
				   context == grammarAccess.getComparisonRule() ||
				   context == grammarAccess.getComparisonAccess().getComparisonLeftAction_1_0() ||
				   context == grammarAccess.getIfElseExpressionRule() ||
				   context == grammarAccess.getIfElseExpressionAccess().getIfElseExpressionConditionAction_1_0() ||
				   context == grammarAccess.getIntLiteralRule() ||
				   context == grammarAccess.getLiteralRule() ||
				   context == grammarAccess.getNumberLiteralRule() ||
				   context == grammarAccess.getPowerRule() ||
				   context == grammarAccess.getPowerAccess().getPowerBaseAction_1_0() ||
				   context == grammarAccess.getProductRule() ||
				   context == grammarAccess.getProductAccess().getProductLeftAction_1_0() ||
				   context == grammarAccess.getRootExpressionRule() ||
				   context == grammarAccess.getTermRule() ||
				   context == grammarAccess.getTermAccess().getTermLeftAction_1_0() ||
				   context == grammarAccess.getUnaryBooleanExpressionRule() ||
				   context == grammarAccess.getUnaryBooleanExpressionAccess().getUnaryBooleanExpressionInnerAction_0_2()) {
					sequence_IntLiteral(context, (IntLiteral) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.MODEL:
				if(context == grammarAccess.getModelRule()) {
					sequence_Model(context, (Model) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.POWER:
				if(context == grammarAccess.getAtomRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionAccess().getBinaryBooleanExpressionLeftAction_1_0() ||
				   context == grammarAccess.getComparisonRule() ||
				   context == grammarAccess.getComparisonAccess().getComparisonLeftAction_1_0() ||
				   context == grammarAccess.getIfElseExpressionRule() ||
				   context == grammarAccess.getIfElseExpressionAccess().getIfElseExpressionConditionAction_1_0() ||
				   context == grammarAccess.getPowerRule() ||
				   context == grammarAccess.getPowerAccess().getPowerBaseAction_1_0() ||
				   context == grammarAccess.getProductRule() ||
				   context == grammarAccess.getProductAccess().getProductLeftAction_1_0() ||
				   context == grammarAccess.getRootExpressionRule() ||
				   context == grammarAccess.getTermRule() ||
				   context == grammarAccess.getTermAccess().getTermLeftAction_1_0() ||
				   context == grammarAccess.getUnaryBooleanExpressionRule() ||
				   context == grammarAccess.getUnaryBooleanExpressionAccess().getUnaryBooleanExpressionInnerAction_0_2()) {
					sequence_Power(context, (Power) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.PRODUCT:
				if(context == grammarAccess.getAtomRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionAccess().getBinaryBooleanExpressionLeftAction_1_0() ||
				   context == grammarAccess.getComparisonRule() ||
				   context == grammarAccess.getComparisonAccess().getComparisonLeftAction_1_0() ||
				   context == grammarAccess.getIfElseExpressionRule() ||
				   context == grammarAccess.getIfElseExpressionAccess().getIfElseExpressionConditionAction_1_0() ||
				   context == grammarAccess.getPowerRule() ||
				   context == grammarAccess.getPowerAccess().getPowerBaseAction_1_0() ||
				   context == grammarAccess.getProductRule() ||
				   context == grammarAccess.getProductAccess().getProductLeftAction_1_0() ||
				   context == grammarAccess.getRootExpressionRule() ||
				   context == grammarAccess.getTermRule() ||
				   context == grammarAccess.getTermAccess().getTermLeftAction_1_0() ||
				   context == grammarAccess.getUnaryBooleanExpressionRule() ||
				   context == grammarAccess.getUnaryBooleanExpressionAccess().getUnaryBooleanExpressionInnerAction_0_2()) {
					sequence_Product(context, (Product) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.TERM:
				if(context == grammarAccess.getAtomRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionAccess().getBinaryBooleanExpressionLeftAction_1_0() ||
				   context == grammarAccess.getComparisonRule() ||
				   context == grammarAccess.getComparisonAccess().getComparisonLeftAction_1_0() ||
				   context == grammarAccess.getIfElseExpressionRule() ||
				   context == grammarAccess.getIfElseExpressionAccess().getIfElseExpressionConditionAction_1_0() ||
				   context == grammarAccess.getPowerRule() ||
				   context == grammarAccess.getPowerAccess().getPowerBaseAction_1_0() ||
				   context == grammarAccess.getProductRule() ||
				   context == grammarAccess.getProductAccess().getProductLeftAction_1_0() ||
				   context == grammarAccess.getRootExpressionRule() ||
				   context == grammarAccess.getTermRule() ||
				   context == grammarAccess.getTermAccess().getTermLeftAction_1_0() ||
				   context == grammarAccess.getUnaryBooleanExpressionRule() ||
				   context == grammarAccess.getUnaryBooleanExpressionAccess().getUnaryBooleanExpressionInnerAction_0_2()) {
					sequence_Term(context, (Term) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.UNARY_BOOLEAN_EXPRESSION:
				if(context == grammarAccess.getAtomRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionRule() ||
				   context == grammarAccess.getBinaryBooleanExpressionAccess().getBinaryBooleanExpressionLeftAction_1_0() ||
				   context == grammarAccess.getComparisonRule() ||
				   context == grammarAccess.getComparisonAccess().getComparisonLeftAction_1_0() ||
				   context == grammarAccess.getIfElseExpressionRule() ||
				   context == grammarAccess.getIfElseExpressionAccess().getIfElseExpressionConditionAction_1_0() ||
				   context == grammarAccess.getPowerRule() ||
				   context == grammarAccess.getPowerAccess().getPowerBaseAction_1_0() ||
				   context == grammarAccess.getProductRule() ||
				   context == grammarAccess.getProductAccess().getProductLeftAction_1_0() ||
				   context == grammarAccess.getRootExpressionRule() ||
				   context == grammarAccess.getTermRule() ||
				   context == grammarAccess.getTermAccess().getTermLeftAction_1_0() ||
				   context == grammarAccess.getUnaryBooleanExpressionRule() ||
				   context == grammarAccess.getUnaryBooleanExpressionAccess().getUnaryBooleanExpressionInnerAction_0_2()) {
					sequence_UnaryBooleanExpression(context, (UnaryBooleanExpression) semanticObject); 
					return; 
				}
				else break;
			}
		if (errorAcceptor != null) errorAcceptor.accept(diagnosticProvider.createInvalidContextOrTypeDiagnostic(semanticObject, context));
	}
	
	/**
	 * Constraint:
	 *     (left=BinaryBooleanExpression_BinaryBooleanExpression_1_0 operation=BooleanOperation right=UnaryBooleanExpression)
	 */
	protected void sequence_BinaryBooleanExpression(EObject context, BinaryBooleanExpression semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.BINARY_BOOLEAN_EXPRESSION__LEFT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.BINARY_BOOLEAN_EXPRESSION__LEFT));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.BINARY_BOOLEAN_EXPRESSION__OPERATION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.BINARY_BOOLEAN_EXPRESSION__OPERATION));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.BINARY_BOOLEAN_EXPRESSION__RIGHT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.BINARY_BOOLEAN_EXPRESSION__RIGHT));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getBinaryBooleanExpressionAccess().getBinaryBooleanExpressionLeftAction_1_0(), semanticObject.getLeft());
		feeder.accept(grammarAccess.getBinaryBooleanExpressionAccess().getOperationBooleanOperationEnumRuleCall_1_1_0(), semanticObject.getOperation());
		feeder.accept(grammarAccess.getBinaryBooleanExpressionAccess().getRightUnaryBooleanExpressionParserRuleCall_1_2_0(), semanticObject.getRight());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     value=EBoolean
	 */
	protected void sequence_BooleanLiteral(EObject context, BooleanLiteral semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.BOOLEAN_LITERAL__VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.BOOLEAN_LITERAL__VALUE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getBooleanLiteralAccess().getValueEBooleanParserRuleCall_0(), semanticObject.isValue());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (left=Comparison_Comparison_1_0 operation=CompareOperation right=Term)
	 */
	protected void sequence_Comparison(EObject context, Comparison semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.COMPARISON__LEFT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.COMPARISON__LEFT));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.COMPARISON__OPERATION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.COMPARISON__OPERATION));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.COMPARISON__RIGHT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.COMPARISON__RIGHT));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getComparisonAccess().getComparisonLeftAction_1_0(), semanticObject.getLeft());
		feeder.accept(grammarAccess.getComparisonAccess().getOperationCompareOperationEnumRuleCall_1_1_0(), semanticObject.getOperation());
		feeder.accept(grammarAccess.getComparisonAccess().getRightTermParserRuleCall_1_2_0(), semanticObject.getRight());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     value=Double
	 */
	protected void sequence_DoubleLiteral(EObject context, DoubleLiteral semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.DOUBLE_LITERAL__VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.DOUBLE_LITERAL__VALUE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getDoubleLiteralAccess().getValueDoubleParserRuleCall_0(), semanticObject.getValue());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     value=EString
	 */
	protected void sequence_FormalParameter(EObject context, FormalParameter semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.FORMAL_PARAMETER__VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.FORMAL_PARAMETER__VALUE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getFormalParameterAccess().getValueEStringParserRuleCall_0(), semanticObject.getValue());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (name=ID (parameters+=RootExpression parameters+=RootExpression*)?)
	 */
	protected void sequence_Function(EObject context, Function semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (condition=IfElseExpression_IfElseExpression_1_0 trueExp=IfElseExpression falseExp=IfElseExpression)
	 */
	protected void sequence_IfElseExpression(EObject context, IfElseExpression semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.IF_ELSE_EXPRESSION__CONDITION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.IF_ELSE_EXPRESSION__CONDITION));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.IF_ELSE_EXPRESSION__TRUE_EXP) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.IF_ELSE_EXPRESSION__TRUE_EXP));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.IF_ELSE_EXPRESSION__FALSE_EXP) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.IF_ELSE_EXPRESSION__FALSE_EXP));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getIfElseExpressionAccess().getIfElseExpressionConditionAction_1_0(), semanticObject.getCondition());
		feeder.accept(grammarAccess.getIfElseExpressionAccess().getTrueExpIfElseExpressionParserRuleCall_1_2_0(), semanticObject.getTrueExp());
		feeder.accept(grammarAccess.getIfElseExpressionAccess().getFalseExpIfElseExpressionParserRuleCall_1_4_0(), semanticObject.getFalseExp());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     value=Integer
	 */
	protected void sequence_IntLiteral(EObject context, IntLiteral semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.INT_LITERAL__VALUE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.INT_LITERAL__VALUE));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getIntLiteralAccess().getValueIntegerParserRuleCall_0(), semanticObject.getValue());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     terms=IfElseExpression
	 */
	protected void sequence_Model(EObject context, Model semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.MODEL__TERMS) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.MODEL__TERMS));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getModelAccess().getTermsIfElseExpressionParserRuleCall_0(), semanticObject.getTerms());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (base=Power_Power_1_0 exponent=Atom)
	 */
	protected void sequence_Power(EObject context, Power semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.POWER__BASE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.POWER__BASE));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.POWER__EXPONENT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.POWER__EXPONENT));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getPowerAccess().getPowerBaseAction_1_0(), semanticObject.getBase());
		feeder.accept(grammarAccess.getPowerAccess().getExponentAtomParserRuleCall_1_2_0(), semanticObject.getExponent());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (left=Product_Product_1_0 operation=ProductOperation right=Power)
	 */
	protected void sequence_Product(EObject context, Product semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.PRODUCT__LEFT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.PRODUCT__LEFT));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.PRODUCT__OPERATION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.PRODUCT__OPERATION));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.PRODUCT__RIGHT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.PRODUCT__RIGHT));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getProductAccess().getProductLeftAction_1_0(), semanticObject.getLeft());
		feeder.accept(grammarAccess.getProductAccess().getOperationProductOperationEnumRuleCall_1_1_0(), semanticObject.getOperation());
		feeder.accept(grammarAccess.getProductAccess().getRightPowerParserRuleCall_1_2_0(), semanticObject.getRight());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (left=Term_Term_1_0 operation=TermOperation right=Product)
	 */
	protected void sequence_Term(EObject context, Term semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.TERM__LEFT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.TERM__LEFT));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.TERM__OPERATION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.TERM__OPERATION));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.TERM__RIGHT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.TERM__RIGHT));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getTermAccess().getTermLeftAction_1_0(), semanticObject.getLeft());
		feeder.accept(grammarAccess.getTermAccess().getOperationTermOperationEnumRuleCall_1_1_0(), semanticObject.getOperation());
		feeder.accept(grammarAccess.getTermAccess().getRightProductParserRuleCall_1_2_0(), semanticObject.getRight());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     inner=UnaryBooleanExpression_UnaryBooleanExpression_0_2
	 */
	protected void sequence_UnaryBooleanExpression(EObject context, UnaryBooleanExpression semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.UNARY_BOOLEAN_EXPRESSION__INNER) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.UNARY_BOOLEAN_EXPRESSION__INNER));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getUnaryBooleanExpressionAccess().getUnaryBooleanExpressionInnerAction_0_2(), semanticObject.getInner());
		feeder.finish();
	}
}
